@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.4.0", __name__, "aws-kms@1.4.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.5.0", __name__, "aws-kms@1.5.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
 class AliasAttributes():
     def __init__(self, *, alias_name: str, alias_target_key: "IKey"):
@@ -716,12 +716,12 @@ class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
         return jsii.sinvoke(cls, "fromKeyArn", [scope, id, key_arn])
 
     @jsii.member(jsii_name="addAlias")
-    def add_alias(self, alias: str) -> "Alias":
+    def add_alias(self, alias_name: str) -> "Alias":
         """Defines a new alias for the key.
 
-        :param alias: -
+        :param alias_name: -
         """
-        return jsii.invoke(self, "addAlias", [alias])
+        return jsii.invoke(self, "addAlias", [alias_name])
 
     @jsii.member(jsii_name="addToResourcePolicy")
     def add_to_resource_policy(self, statement: aws_cdk.aws_iam.PolicyStatement, allow_no_op: typing.Optional[bool]=None) -> None:
